'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = chatbaseMiddleware;

var _chatbase2 = require('@google/chatbase');

var _chatbase3 = _interopRequireDefault(_chatbase2);

var _setInterceptors = require('./setInterceptors');

var _setInterceptors2 = _interopRequireDefault(_setInterceptors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function chatbaseMiddleware(bot, { apiKey, platform }) {
  const chatbase = _chatbase3.default.setApiKey(apiKey).setPlatform(platform);

  (0, _setInterceptors2.default)(bot, chatbase);

  return (req, res, next) => {
    req.body.entry.forEach(entry => {
      let messaging;
      if (entry.messaging) {
        messaging = entry.messaging[0];
      } else if (entry.standby) {
        messaging = entry.standby[0];
      } else {
        return;
      }

      const { id } = messaging.sender;
      let logMessage;

      if (messaging.message && messaging.message.text) {
        logMessage = `Text: ${messaging.message.text}`;
      } else if (messaging.message && messaging.message.quick_reply) {
        logMessage = `Quick Reply Payload: ${messaging.message.quick_reply.payload}`;
      } else if (messaging.postback) {
        logMessage = `Postback Payload: ${messaging.postback.payload}`;
      } else {
        return;
      }

      chatbase.newMessage().setAsTypeUser().setUserId(id).setTimestamp(Date.now().toString()).setMessage(logMessage).send().catch(console.error);
    });

    next();
  };
}